Learn R Programming

esemifar (version 2.0.1)

arma_to_ar: AR Representation of an ARMA Model

Description

Output has representation with positive signs (on the right-hand side of the equation); inputs are both with positive signs (on right-hand side of equation).

Usage

arma_to_ar(ar = numeric(0), ma = numeric(0), max_i = 1000)

Value

A numeric vector is returned.

Arguments

ar

the AR-coefficient series ordered by lag.

ma

the MA-coefficient series ordered by lag.

max_i

the maximum index up until which to return the coefficient series.

Author

  • Dominik Schulz (Scientific Employee) (Department of Economics, Paderborn University),
    Author

Details

Consider the ARMA model $$X_t = ar_1 X_{t-1} + ... + ar_p X_{t-p}+ma_1 e_{t-1}+...+ma_q e_{t-q}+e_t,$$ where \(e_t\) are the innovations. \(ar_i\), \(i=1, ..., p\), are the AR-coefficients to pass to the argument ar, \(ma_j\), \(j = 1, ..., q\), are the MA-coefficients to pass to the argument ma.The function then returns the coefficients from the corresponding infinite-order AR-representation $$-e_t = c_0 X_t + c_1 X_{t-1}+c_2 X_{t-2} + c_3 X_{t-3} + ...,$$ where \(c_l\), \(l = 0, 1, 2, ...\), are the coefficients. Following this notation, \(c_0 = -1\) by definition.

Examples

Run this code
arma_to_ar(ar = 0.75, ma = 0.5, max_i = 100)

Run the code above in your browser using DataLab