Learn R Programming

esemifar (version 2.0.1)

d_to_coef: Filter Coefficients of the Fractional Differencing Operator

Description

Output is with positive signs on the left-hand side of the equation.

Usage

d_to_coef(d, max_i = 1000)

Value

A numeric vector is returned.

Arguments

d

the fractional differencing coefficient.

max_i

the maximum index up until which to return the coefficient series.

Author

  • Dominik Schulz (Scientific Employee) (Department of Economics, Paderborn University),
    Author

Details

Consider the FARIMA model $$(1-B)^d Y_t = ar_1 X_{t-1} + ... + ar_p X_{t-p}+ma_1 e_{t-1}+...+ma_q e_{t-q}+e_t,$$ where \(e_t\) are the innovations and where \(X_t=(1-B)^d Y_t\). \(d\) is the fractional differencing coefficient.

The fractional differencing operator \((1-B)^d\) can alternatively be expressed as an infinite coefficient series, so that $$(1-B)^d=\sum_{l=0}^{\infty}b_l B^k,$$ where \(B\) is the backshift operator and where \(b_l\), \(l=0,1,2,...\), are the coefficients. Note that \(b_0=1\) by definition.

The function returns the series of coefficients \(\{b_l, l =0,1,2,...\}\).

Examples

Run this code
d_to_coef(d = 0.3, max_i = 100)

Run the code above in your browser using DataLab