Learn R Programming

esemifar (version 2.0.1)

farima_to_ar: AR Representation of a FARIMA Model

Description

Output has representation with positive signs (on the right-hand side of the equation); inputs are both with positive signs (on right-hand side of equation).

Usage

farima_to_ar(ar = numeric(0), ma = numeric(0), d = 0, max_i = 1000)

Value

A numeric vector is returned.

Arguments

ar

the AR-coefficient series ordered by lag.

ma

the MA-coefficient series ordered by lag.

d

the fractional differencing coefficient.

max_i

the maximum index up until which to return the coefficient series.

Author

  • Dominik Schulz (Scientific Employee) (Department of Economics, Paderborn University),
    Author

Details

Consider the FARIMA model $$(1-B)^d Y_t = ar_1 X_{t-1} + ... + ar_p X_{t-p}+ma_1 e_{t-1}+...+ma_q e_{t-q}+e_t,$$ where \(e_t\) are the innovations and where \(X_t=(1-B)^d Y_t\). \(ar_i\), \(i=1, ..., p\), are the AR-coefficients to pass to the argument ar, \(ma_j\), \(j = 1, ..., q\), are the MA-coefficients to pass to the argument ma. \(d\) is the fractional differencing coefficient. The function then returns the coefficients from the corresponding infinite-order AR-representation $$-e_t = c_0 Y_t + c_1 Y_{t-1}+c_2 Y_{t-2} + c_3 Y_{t-3} + ...,$$ where \(c_l\), \(l = 0, 1, 2, ...\), are the coefficients. Following this notation, \(c_0 = -1\) by definition.

Examples

Run this code
farima_to_ar(ar = 0.75, ma = 0.5, d = 0.3, max_i = 100)

Run the code above in your browser using DataLab