residuals.esemifar: Extract Model Residuals
Description
Generic function which extracts model residuals from a esemifar class
object. Both residuals and its abbreviated form resid can be called.
Usage
# S3 method for esemifar
residuals(object, ...)
Value
Residuals extracted from a esemifar class object.
Arguments
- object
an object from the esemifar class.
- ...
included for consistency with the generic function.